# Copyright 1999-2005 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/net-wireless/ndiswrapper/ndiswrapper-1.0_rc4.ebuild,v 1.1 2005/01/23 10:31:10 cardoe Exp $

inherit linux-mod eutils

DESCRIPTION="Wrapper for using Windows drivers for some wireless cards"
HOMEPAGE="http://ndiswrapper.sourceforge.net/"
SRC_URI="mirror://sourceforge/${PN}/${PN}-1.0rc4.tar.gz"

LICENSE="GPL-2"
KEYWORDS="~x86 ~amd64"

IUSE="debug 4kstacks"
DEPEND="sys-apps/pciutils"
S=${WORKDIR}/${PN}-1.0rc4

if use !4kstacks
then
	CONFIG_CHECK="!4KSTACKS"
	4KSTACKS_ERROR="CONFIG_4KSTACKS should not be set.\nIf you feel really confident that 4K Stacks will work for you, add '4kstacks' to your USE flags. But don't expect any support from Gentoo."
fi

CONFIG_CHECK="${CONFIG_CHECK} NET_RADIO"

MODULE_NAMES="ndiswrapper(misc:${S}/driver)"
BUILD_PARAMS="KSRC=${ROOT}${KV_DIR} KVERS=${KV_MAJOR}${KV_MINOR}"
BUILD_TARGETS="all"
MODULESD_NDISWRAPPER_ALIASES=("wlan0 ndiswrapper")

src_unpack() {
	unpack ${A}

	if grep '# CONFIG_SOFTWARE_SUSPEND2 is not set' ${ROOT}${KV_DIR}/.config
	then
		eerror "You have a kernel patched with Software Suspend 2 (swsusp2)"
		eerror "but don't have it enabled. You must remove the patch or"
		eerror "enable Software Suspend 2 (swsusp2)."
		eerror "http://bugs.gentoo.org/show_bug.cgi?id=74864"
		die "Please fix your kernel"
	fi

	convert_to_m ${S}/driver/Makefile
}

src_compile() {
	# Enable verbose debugging information
	use debug && export DEBUG=3

	cd utils
	emake || die "Compile of utils failed!"

	linux-mod_src_compile

}

src_install() {
	dosbin utils/ndiswrapper
	dosbin utils/ndiswrapper-buginfo

	into /
	dosbin utils/loadndisdriver

	dodoc README INSTALL AUTHORS ChangeLog
	doman ndiswrapper.8

	keepdir /etc/ndiswrapper

	linux-mod_src_install
}

pkg_postinst() {
	linux-mod_pkg_postinst
	echo
	einfo "ndiswrapper requires .inf and .sys files from a Windows(tm) driver"
	einfo "to function. Download these to /root for example, then"
	einfo "run 'ndiswrapper -i /root/foo.inf'. After that you can delete them."
	einfo "They will be copied to the proper location."
	einfo "Once done, please run 'update-modules'."
	echo
	einfo "check http://ndiswrapper.sf.net/supported_chipsets.html for drivers"
	I=`lspci -n | egrep 'Class (0280|0200):' |  cut -d' ' -f4`
	einfo "Look for the following on that page for your driver:"
	einfo ${I}
	echo
	einfo "Please have a look at http://ndiswrapper.sourceforge.net/wiki/"
	einfo "for the FAQ, HowTos, Tips, Configuration, and installation"
	einfo "information."
	echo
	einfo "You MUST re-install your Windows drivers."
	einfo "Best way to do this is to run the following commands"
	einfo "mv /etc/ndiswrapper/{driver} /tmp"
	einfo "ndiswrapper -i /tmp/{driver}/{driver}.inf"
	ebeep
	ebeep
	ebeep
}
